pub struct ReprOptions {
pub int_specified: bool,
pub typ: Ty,
pub align: Option<Align>,
pub pack: Option<Align>,
pub flags: ReprFlags,
}Expand description
Reflects [ty::ReprOptions]
Fields
int_specified: boolWhether an explicit integer representation was specified.
typ: TyThe actual discriminant type resulting from the representation options.
align: Option<Align>pack: Option<Align>flags: ReprFlagsTrait Implementations
Sourceimpl Clone for ReprOptions
impl Clone for ReprOptions
Sourcefn clone(&self) -> ReprOptions
fn clone(&self) -> ReprOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReprOptions
impl Debug for ReprOptions
Sourceimpl<'de> Deserialize<'de> for ReprOptions
impl<'de> Deserialize<'de> for ReprOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ReprOptions
impl Hash for ReprOptions
Sourceimpl JsonSchema for ReprOptions
impl JsonSchema for ReprOptions
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ReprOptions
impl Ord for ReprOptions
Sourcefn cmp(&self, other: &ReprOptions) -> Ordering
fn cmp(&self, other: &ReprOptions) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ReprOptions
impl PartialEq for ReprOptions
Sourceimpl PartialOrd for ReprOptions
impl PartialOrd for ReprOptions
Sourceimpl<'tcx, S: UnderOwnerState<'tcx>> SInto<S, ReprOptions> for ReprOptions
impl<'tcx, S: UnderOwnerState<'tcx>> SInto<S, ReprOptions> for ReprOptions
fn sinto(&self, s: &S) -> ReprOptions
Sourceimpl Serialize for ReprOptions
impl Serialize for ReprOptions
impl Eq for ReprOptions
impl StructuralPartialEq for ReprOptions