super_clause_to_clause_and_impl_expr

Function super_clause_to_clause_and_impl_expr 

pub fn super_clause_to_clause_and_impl_expr<'tcx, S: UnderOwnerState<'tcx>>(
    s: &S,
    impl_did: DefId,
    item_did: DefId,
    clause: Clause<'tcx>,
    span: Span,
) -> Option<(Clause, ImplExpr, Span)>
Given a clause clause declared on item_did’s counterpart in the trait that impl_did implements, substitutes the impl’s arguments into it and (1) derives a Clause and (2) resolves an ImplExpr. item_did is impl_did itself for a clause of the trait, or one of the impl’s associated items for a clause of that item; the latter appends a generic associated type’s own parameters, which is the arity the declared clause expects.